package com.fjhx.tenant.utils;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.system.service.ISysDeptService;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

public class DeptUstil {

    private static final ISysDeptService sysDeptService = SpringUtil.getBean(ISysDeptService.class);

    /**
     * 根据部门id获取公司信息
     */
    public static SysDept getCompanyByDeptId(Long deptId) {
        SysDept dept = sysDeptService.getById(deptId);
        if (ObjectUtil.isEmpty(dept)) {
            throw new ServiceException("查询不到该部门公司信息");
        }
        if (Objects.equals(dept.getType(), 0)) {
            return dept;
        }
        return getCompanyByDeptId(dept.getParentId());
    }

    public static Long getCompanyIdByDeptId(Long deptId) {
        return getCompanyByDeptId(deptId).getDeptId();
    }

    /**
     * 根据部门id列表获取部门名称
     */
    public static Map<Long, String> getDeptNameMap(List<Long> deptIds) {
        List<SysDept> deptList = sysDeptService.list(Wrappers.<SysDept>query()
                .in(ObjectUtil.isNotEmpty(deptIds), "dept_id", deptIds)
        );
        return deptList.stream().collect(Collectors.toMap(SysDept::getDeptId, SysDept::getDeptName));
    }


}
